@@ -6,7 +6,6 @@ use Exporter ();
 use Apache::Constants qw(OK DECLINED);
 use Apache::Connection ();
 use Apache::Server ();
-use Apache::SIG ();
 
 @Apache::EXPORT_OK = qw(exit warn);
 
@@ -16,8 +15,6 @@ if (caller eq "CGI::Apache") {
     #we must die here outside of httpd so CGI::Switch works
     die unless $ENV{MOD_PERL};
 }
- 
-Apache::SIG->set;
 
 {
     no strict;
@@ -41,7 +38,7 @@ sub parse_args {
     my($wantarray,$string) = @_;
     return unless defined $string and $string;
     if(defined $wantarray and $wantarray) {
-	return map { Apache::unescape_url_info($_) } split /[=&]/, $string, -1;
+	return map { Apache::unescape_url_info($_) } split /[=&;]/, $string, -1;
     }
     $string;
 }
@@ -703,13 +700,24 @@ optionally set the value of a named entry.  This table is used by Apache
 modules to pass messages amongst themselves. Generally if you are
 writing handlers in mod_perl you can use Perl variables for this.
 
-   $r->notes("MY_HANDLER", OK);
+   $r->notes("MY_HANDLER" => OK);
    $val = $r->notes("MY_HANDLER");
 
 Will return a I<HASH> reference blessed into the I<Apache::Table>
 class when called in a scalar context with no "key" argument. This
 requires I<Apache::Table>.
 
+=item $r->pnotes( $key, [$value] )
+
+Like $r->notes, but takes any scalar as an value.
+
+   $r->pnotes("MY_HANDLER" => [qw(one two)]);
+   my $val = $r->pnotes("MY_HANDLER");
+   print $val->[0];     # prints "one"
+
+Advantage over just using a Perl variable is that $r->pnotes gets
+cleaned up after every request.
+
 =item $r->subprocess_env( $key, [$value] )
 
 Return the value of a named entry in the Apache C<subprocess_env>
