@@ -2,7 +2,7 @@ package Apache::File;
 
 use strict;
 use Fcntl ();
-use Apache ();
+use mod_perl ();
 
 {
     no strict;
@@ -13,7 +13,7 @@ use Apache ();
 my $TMPNAM = 'aaaaaa';
 my $TMPDIR = $ENV{'TMPDIR'} || $ENV{'TEMP'} || '/tmp';
 ($TMPDIR) = $TMPDIR =~ /^([^<>|;*]+)$/; #untaint
-my $Mode = Fcntl::O_WRONLY()|Fcntl::O_EXCL()|Fcntl::O_CREAT();
+my $Mode = Fcntl::O_RDWR()|Fcntl::O_EXCL()|Fcntl::O_CREAT();
 my $Perms = 0600;
  
 sub tmpfile {
