@@ -1,6 +1,6 @@
 package Bundle::Apache;
 
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 1;
 
@@ -20,15 +20,17 @@ Apache - Perl interface to Apache server API
 
 ExtUtils::Embed - Needed to build httpd
 
-LWP::UserAgent - Web client to run mod_perl tests
+MIME::Base64 - Needed for LWP
+
+URI::URL - Needed for LWP
+
+LWP - Web client to run mod_perl tests
 
 HTML::TreeBuilder - Used for Apache::SSI
 
-MIME::Base64 - Needed for LWP
-
 Devel::Symdump - Symbol table browsing with Apache::Status
 
-HTTPD::UserAdmin - Apache::Authen stuff
+Data::Dumper - Used by Apache::PerlSections->dump
 
 CGI - CGI.pm
 
